@@ -14,12 +14,12 @@ import (
 
 	"github.com/facette/natsort"
 
-	"github.com/johnkerl/miller/pkg/lib"
-	"github.com/johnkerl/miller/pkg/mlrval"
-	"github.com/johnkerl/miller/pkg/runtime"
+	"github.com/johnkerl/miller/v6/pkg/lib"
+	"github.com/johnkerl/miller/v6/pkg/mlrval"
+	"github.com/johnkerl/miller/v6/pkg/runtime"
 )
 
-// Most function types are in the github.com/johnkerl/miller/pkg/types package. These types, though,
+// Most function types are in the github.com/johnkerl/miller/v6/pkg/types package. These types, though,
 // include functions which need to access CST state in order to call back to
 // user-defined functions.  To avoid a package-cycle dependency, they are
 // defined here.
@@ -875,7 +875,7 @@ func sortAF(
 	return mlrval.FromArray(outputArray)
 }
 
-// sortAF implements sort on arrays with callback UDF.
+// sortMF implements sort on arrays with callback UDF.
 func sortMF(
 	input1 *mlrval.Mlrval,
 	input2 *mlrval.Mlrval,
