@@ -3,7 +3,7 @@ package input
 import (
 	"regexp"
 
-	"github.com/johnkerl/miller/pkg/cli"
+	"github.com/johnkerl/miller/v6/pkg/cli"
 )
 
 func NewRecordReaderMarkdown(
