@@ -186,8 +186,7 @@ func getRecordBatchExplicitTSVHeader(
 		} else {
 			if !reader.readerOptions.AllowRaggedCSVInput && len(reader.headerStrings) != len(fields) {
 				err := fmt.Errorf(
-					"mlr: TSV header/data length mismatch %d != %d "+
-						"at filename %s line  %d.\n",
+					"mlr: TSV header/data length mismatch %d != %d at filename %s line %d",
 					len(reader.headerStrings), len(fields), filename, reader.inputLineNumber,
 				)
 				errorChannel <- err
@@ -307,8 +306,7 @@ func getRecordBatchImplicitTSVHeader(
 		} else {
 			if !reader.readerOptions.AllowRaggedCSVInput && len(reader.headerStrings) != len(fields) {
 				err := fmt.Errorf(
-					"mlr: TSV header/data length mismatch %d != %d "+
-						"at filename %s line  %d.\n",
+					"mlr: TSV header/data length mismatch %d != %d at filename %s line %d",
 					len(reader.headerStrings), len(fields), filename, reader.inputLineNumber,
 				)
 				errorChannel <- err
