@@ -360,7 +360,7 @@ func (mlrmap *Mlrmap) getWithMlrvalArrayIndex(index *Mlrval) (*Mlrval, error) {
 		}
 		if i < n-1 {
 			if !next.IsMap() {
-				return nil, fmt.Errorf("mlr: cannot multi-index non-map.")
+				return nil, fmt.Errorf("mlr: cannot multi-index non-map")
 			}
 			current = next.intf.(*Mlrmap)
 		} else {
@@ -378,7 +378,7 @@ func (mlrmap *Mlrmap) getWithMlrvalSingleIndex(index *Mlrval) (*Mlrval, error) {
 		return mlrmap.Get(index.String()), nil
 	} else {
 		return nil, fmt.Errorf(
-			"Record/map indices must be string, int, or array thereof; got %s", index.GetTypeName(),
+			"record/map indices must be string, int, or array thereof; got %s", index.GetTypeName(),
 		)
 	}
 }
