@@ -156,7 +156,7 @@ func NewTransformerSeqgen(
 		if fstart == fstop {
 			doneComparator = bifs.BIF_equals
 		} else {
-			return nil, fmt.Errorf("mlr seqgen: step must not be zero unless start == stop.")
+			return nil, fmt.Errorf("mlr seqgen: step must not be zero unless start == stop")
 		}
 	}
 
@@ -192,9 +192,7 @@ func (tr *TransformerSeqgen) Transform(
 		case b := <-inputDownstreamDoneChannel:
 			outputDownstreamDoneChannel <- b
 			keepGoing = false
-			break
 		default:
-			break
 		}
 		if !keepGoing {
 			break
